==> sqlmesh-0.53.3.dev7.tar.gz: sqlmesh-0.53.3.dev7/tests/fixtures/migrations/33/load.sql <==
COPY raw.demographics FROM 'test_export/raw_demographics.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_revenue_by_day__3608812833 FROM 'test_export/sqlmesh__sushi_sushi__waiter_revenue_by_day____________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_revenue_by_day__3608812833__temp FROM 'test_export/sqlmesh__sushi_sushi__waiter_revenue_by_day______________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_as_customer_by_day__2887908243 FROM 'test_export/sqlmesh__sushi_sushi__waiter_as_customer_by_day____________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_as_customer_by_day__2887908243__temp FROM 'test_export/sqlmesh__sushi_sushi__waiter_as_customer_by_day______________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_revenue_by_day__1623050846 FROM 'test_export/sqlmesh__sushi_sushi__waiter_revenue_by_day_____________1.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_revenue_by_day__1623050846__temp FROM 'test_export/sqlmesh__sushi_sushi__waiter_revenue_by_day______________temp_1.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__customers__3386317773 FROM 'test_export/sqlmesh__sushi_sushi__customers____________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__customers__3386317773__temp FROM 'test_export/sqlmesh__sushi_sushi__customers______________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__customer_revenue_lifetime__439196980 FROM 'test_export/sqlmesh__sushi_sushi__customer_revenue_lifetime___________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__customer_revenue_lifetime__439196980__temp FROM 'test_export/sqlmesh__sushi_sushi__customer_revenue_lifetime_____________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__customer_revenue_by_day__489697783 FROM 'test_export/sqlmesh__sushi_sushi__customer_revenue_by_day___________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__customer_revenue_by_day__489697783__temp FROM 'test_export/sqlmesh__sushi_sushi__customer_revenue_by_day_____________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__order_items__2521328603 FROM 'test_export/sqlmesh__sushi_sushi__order_items____________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__order_items__2521328603__temp FROM 'test_export/sqlmesh__sushi_sushi__order_items______________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__marketing__3476342839 FROM 'test_export/sqlmesh__sushi_sushi__marketing____________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__marketing__3476342839__temp FROM 'test_export/sqlmesh__sushi_sushi__marketing______________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_names__235351925 FROM 'test_export/sqlmesh__sushi_sushi__waiter_names___________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_names__235351925__temp FROM 'test_export/sqlmesh__sushi_sushi__waiter_names_____________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__raw_marketing__3933936918 FROM 'test_export/sqlmesh__sushi_sushi__raw_marketing____________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__raw_marketing__3933936918__temp FROM 'test_export/sqlmesh__sushi_sushi__raw_marketing______________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__orders__1740723439 FROM 'test_export/sqlmesh__sushi_sushi__orders____________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__orders__1740723439__temp FROM 'test_export/sqlmesh__sushi_sushi__orders______________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__items__115405787 FROM 'test_export/sqlmesh__sushi_sushi__items___________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__items__115405787__temp FROM 'test_export/sqlmesh__sushi_sushi__items_____________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh._plan_dags FROM 'test_export/sqlmesh__plan_dags.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh._intervals FROM 'test_export/sqlmesh__intervals.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh._seeds FROM 'test_export/sqlmesh__seeds.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh._versions FROM 'test_export/sqlmesh__versions.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh._environments FROM 'test_export/sqlmesh__environments.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh._snapshots FROM 'test_export/sqlmesh__snapshots.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);

==> sqlmesh-0.54.1.dev21.tar.gz: sqlmesh-0.54.1.dev21/tests/fixtures/migrations/33/load.sql <==
COPY raw.demographics FROM 'test_export/raw_demographics.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_revenue_by_day__3608812833 FROM 'test_export/sqlmesh__sushi_sushi__waiter_revenue_by_day____________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_revenue_by_day__3608812833__temp FROM 'test_export/sqlmesh__sushi_sushi__waiter_revenue_by_day______________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_as_customer_by_day__1695007643 FROM 'test_export/sqlmesh__sushi_sushi__waiter_as_customer_by_day____________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_as_customer_by_day__1695007643__temp FROM 'test_export/sqlmesh__sushi_sushi__waiter_as_customer_by_day______________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_revenue_by_day__1623050846 FROM 'test_export/sqlmesh__sushi_sushi__waiter_revenue_by_day_____________1.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_revenue_by_day__1623050846__temp FROM 'test_export/sqlmesh__sushi_sushi__waiter_revenue_by_day______________temp_1.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__customers__137303981 FROM 'test_export/sqlmesh__sushi_sushi__customers___________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__customers__137303981__temp FROM 'test_export/sqlmesh__sushi_sushi__customers_____________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__customer_revenue_lifetime__439196980 FROM 'test_export/sqlmesh__sushi_sushi__customer_revenue_lifetime___________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__customer_revenue_lifetime__439196980__temp FROM 'test_export/sqlmesh__sushi_sushi__customer_revenue_lifetime_____________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__customer_revenue_by_day__489697783 FROM 'test_export/sqlmesh__sushi_sushi__customer_revenue_by_day___________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__customer_revenue_by_day__489697783__temp FROM 'test_export/sqlmesh__sushi_sushi__customer_revenue_by_day_____________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__order_items__2521328603 FROM 'test_export/sqlmesh__sushi_sushi__order_items____________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__order_items__2521328603__temp FROM 'test_export/sqlmesh__sushi_sushi__order_items______________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__marketing__3476342839 FROM 'test_export/sqlmesh__sushi_sushi__marketing____________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__marketing__3476342839__temp FROM 'test_export/sqlmesh__sushi_sushi__marketing______________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_names__235351925 FROM 'test_export/sqlmesh__sushi_sushi__waiter_names___________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__waiter_names__235351925__temp FROM 'test_export/sqlmesh__sushi_sushi__waiter_names_____________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__raw_marketing__3933936918 FROM 'test_export/sqlmesh__sushi_sushi__raw_marketing____________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__raw_marketing__3933936918__temp FROM 'test_export/sqlmesh__sushi_sushi__raw_marketing______________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__orders__1740723439 FROM 'test_export/sqlmesh__sushi_sushi__orders____________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__orders__1740723439__temp FROM 'test_export/sqlmesh__sushi_sushi__orders______________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__items__115405787 FROM 'test_export/sqlmesh__sushi_sushi__items___________.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh__sushi.sushi__items__115405787__temp FROM 'test_export/sqlmesh__sushi_sushi__items_____________temp.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh._plan_dags FROM 'test_export/sqlmesh__plan_dags.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh._intervals FROM 'test_export/sqlmesh__intervals.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh._seeds FROM 'test_export/sqlmesh__seeds.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh._versions FROM 'test_export/sqlmesh__versions.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh._environments FROM 'test_export/sqlmesh__environments.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
COPY sqlmesh._snapshots FROM 'test_export/sqlmesh__snapshots.csv' (FORMAT 'csv', quote '"', delimiter ',', header 1);
